@@ -33,26 +33,25 @@
 #include <config.h>
 #endif
 
-#include <rcsc/math_util.h>
-#include <rcsc/soccer_math.h>
-#include <rcsc/geom/rect_2d.h>
-#include <rcsc/geom/sector_2d.h>
-#include <rcsc/param/server_param.h>
-
-#include <rcsc/player/debug_client.h>
-#include <rcsc/player/interception.h>
-#include <rcsc/player/logger.h>
-#include <rcsc/player/audio_sensor.h>
-#include <rcsc/player/player_agent.h>
+#include "body_pass.h"
 
+#include "intention_kick.h"
 #include "body_kick_two_step.h"
 #include "body_kick_multi_step.h"
 #include "body_stop_ball.h"
 #include "body_hold_ball.h"
 
-#include "intention_kick.h"
+#include <rcsc/player/interception.h>
+#include <rcsc/player/logger.h>
+#include <rcsc/player/player_agent.h>
+#include <rcsc/player/debug_client.h>
+#include <rcsc/player/audio_sensor.h>
 
-#include "body_pass.h"
+#include <rcsc/param/server_param.h>
+#include <rcsc/geom/rect_2d.h>
+#include <rcsc/geom/sector_2d.h>
+#include <rcsc/soccer_math.h>
+#include <rcsc/math_util.h>
 
 namespace rcsc {
 
@@ -837,8 +836,7 @@ Body_Pass::create_through_pass(const WorldModel & world,
     AngleDeg dash_angle = S_min_angle;
     for ( int i = 0; i < S_angle_loop; i++, dash_angle += S_angle_inc )
     {
-        const Vector2D base_dash( Vector2D::POLE,
-                                        S_min_dash, dash_angle );
+        const Vector2D base_dash = Vector2D::polar2vector( S_min_dash, dash_angle );
 
         // dash dist loop
         double dash_dist = S_min_dash;
@@ -967,8 +965,7 @@ Body_Pass::verify_direct_pass( const WorldModel & world,
 {
     static const double player_dash_speed = 1.0;
 
-    const Vector2D first_vel( Vector2D::POLE,
-                                    first_speed, target_angle );
+    const Vector2D first_vel = Vector2D::polar2vector( first_speed, target_angle );
     const AngleDeg minus_target_angle = -target_angle;
     const double next_speed = first_speed * ServerParam::i().ballDecay();
 
@@ -1135,8 +1132,7 @@ Body_Pass::verify_through_pass( const WorldModel &world,
 {
     static const double player_dash_speed = 1.0;
 
-    const Vector2D first_vel( Vector2D::POLE,
-                                    first_speed, target_angle );
+    const Vector2D first_vel = Vector2D::polar2vector( first_speed, target_angle );
     const AngleDeg minus_target_angle = -target_angle;
     const double next_speed = first_speed * ServerParam::i().ballDecay();
 
@@ -1288,12 +1284,12 @@ Body_Pass::evaluate_routes( const WorldModel & world )
         {
             double x_diff = it->receive_point_.x - world.self().pos().x;
             x_diff_rate = std::pow( 0.98,
-                                    std::max( 0.0, 20.0 - x_diff ) );
+                                    std::max( 0.0, 30.0 - x_diff ) );
         }
         //-----------------------------------------------------------
-        double receiver_move_rate
-            = std::pow( 0.995,
-                        it->receiver_->pos().dist( it->receive_point_ ) );
+        double receiver_move_rate = 1.0;
+        //= std::pow( 0.995,
+        //it->receiver_->pos().dist( it->receive_point_ ) );
         //-----------------------------------------------------------
         double pos_conf_rate = std::pow( 0.98, it->receiver_->posCount() );
         //-----------------------------------------------------------
@@ -1305,6 +1301,11 @@ Body_Pass::evaluate_routes( const WorldModel & world )
             dir_conf_rate = std::pow( 0.95, dir_count );
         }
         //-----------------------------------------------------------
+        double offense_rate
+            = std::pow( 0.98,
+                        std::max( 5.0, std::fabs( it->receive_point_.y
+                                                  - world.ball().pos().y ) ) );
+        //-----------------------------------------------------------
         const Sector2D sector( it->receive_point_,
                                      0.0, 10.0,
                                      min_angle, max_angle );
@@ -1323,6 +1324,7 @@ Body_Pass::evaluate_routes( const WorldModel & world )
         it->score_ *= receiver_move_rate;
         it->score_ *= pos_conf_rate;
         it->score_ *= dir_conf_rate;
+        it->score_ *= offense_rate;
         it->score_ *= front_space_rate;
 
         if ( it->one_step_kick_ )
@@ -1358,8 +1360,7 @@ Body_Pass::can_kick_by_one_step( const WorldModel & world,
                                  const double & first_speed,
                                  const AngleDeg & target_angle )
 {
-    Vector2D required_accel( Vector2D::POLE,
-                             first_speed, target_angle );
+    Vector2D required_accel = Vector2D::polar2vector( first_speed, target_angle );
     required_accel -= world.ball().vel();
     return ( world.self().kickRate() * ServerParam::i().maxPower()
              > required_accel.r() );
