@@ -30,14 +30,14 @@
 /////////////////////////////////////////////////////////////////////
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
-#include <vector>
-#include <algorithm>
-
 #include "angle_deg.h"
 
+#include <algorithm>
+#include <vector>
+
 #ifndef M_PI
 //! PI value macro
 #define M_PI 3.14159265358979323846
