@@ -30,15 +30,17 @@
 /////////////////////////////////////////////////////////////////////
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
-#include <cmath>
-
 #include "vector_2d.h"
 
+#include <cmath>
+
 namespace rcsc {
 
 const double Vector2D::ERROR_VALUE = HUGE_VAL; // defined in cmath (math.h)
 
+const Vector2D Vector2D::INVALIDATED( Vector2D::ERROR_VALUE, Vector2D::ERROR_VALUE );
+
 }
