@@ -32,11 +32,11 @@
 #ifndef RCSC_GEOM_VECTOR2D_H
 #define RCSC_GEOM_VECTOR2D_H
 
+#include <rcsc/geom/angle_deg.h>
+
+#include <functional>
 #include <iostream>
 #include <cmath>
-#include <functional>
-
-#include <rcsc/geom/angle_deg.h>
 
 namespace rcsc {
 
@@ -52,27 +52,12 @@ class Vector2D {
 
 public:
 
-    /*!
-      \enum InvalidType
-      \brief type definition to assign invalid value
-
-      This type is used only to create invalid Vector2D instance.
-     */
-    enum InvalidType {
-        INVALID
-    };
-
-    /*!
-      \enum PoleType
-      \brief type definition to assign value by polar
-    */
-    enum PoleType {
-        POLE, //!< polar coordinate
-    };
-
     //! constant error value for XY.
     static const double ERROR_VALUE;
 
+    //! invalidated value vector
+    static const Vector2D INVALIDATED;
+
     double x; //!< X coordinate
     double y; //!< Y coordinate
 
@@ -95,29 +80,6 @@ public:
         , y( yy )
       { }
 
-    /*!
-      \brief construct with POLAR value
-      \param pole always POLE
-      \param radius vector's radius
-      \param dir vector's angle
-    */
-    Vector2D( PoleType pole,
-              const double & radius,
-              const AngleDeg & dir )
-        : x( radius * dir.cos() )
-        , y( radius * dir.sin() )
-      { }
-
-    /*!
-      \brief create vector that has invalid value.
-      \param v invalid type
-     */
-    explicit
-    Vector2D( const InvalidType v )
-        : x( ERROR_VALUE )
-        , y( ERROR_VALUE )
-      { }
-
     /*!
       \brief check if this vector has validate values.
       \return true if value is validate.
@@ -127,6 +89,15 @@ public:
           return ( ( x != ERROR_VALUE ) && ( y != ERROR_VALUE ) );
       }
 
+    /*!
+      \brief type conversion operator. alias of valid().
+      \return true if value is validate.
+     */
+    operator bool() const
+      {
+          return valid();
+      }
+
     /*!
       \brief assign XY value directly.
       \param xx assigned x value
@@ -157,30 +128,11 @@ public:
           return *this;
       }
 
-    /*!
-      \brief assign XY value from POLAR value.
-      \param type always POLE
-      \param radius vector's radius
-      \param dir vector's angle
-      \return const reference to itself
-     */
     const
-    Vector2D & assign( PoleType type,
-                       const double & radius,
-                       const AngleDeg & dir )
+    Vector2D & invalidate()
       {
-          return setPolar( radius, dir );
-      }
-
-    /*!
-      \brief assign invalid value
-      \param v invalid type
-      \return const reference to itself
-     */
-    const
-    Vector2D & assign( const InvalidType v )
-      {
-          x = y = ERROR_VALUE;
+          x = ERROR_VALUE;
+          y = ERROR_VALUE;
           return *this;
       }
 
