@@ -30,17 +30,18 @@
 /////////////////////////////////////////////////////////////////////
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
+#include "gzfstream.h"
+
+#include <string>
+#include <cstdio>
+
 #ifdef HAVE_LIBZ
 #include <zlib.h>
 #endif
 
-#include <string>
-#include <cstdio>
-#include "gzfstream.h"
-
 namespace rcsc {
 
 /////////////////////////////////////////////////////////////////////
@@ -126,7 +127,7 @@ gzfilebuf::open( const char * path,
                  std::ios_base::openmode mode,
                  int level, int strategy )
 {
-    gzfilebuf* ret = NULL;
+    gzfilebuf * ret = NULL;
 #ifdef HAVE_LIBZ
     if ( ! M_impl )
     {
@@ -178,12 +179,14 @@ gzfilebuf::open( const char * path,
             this->setg( M_buf, M_buf, M_buf );
             M_impl->open_mode_ = std::ios_base::in;
         }
+
         if ( testo )
         {
             //std::cerr << "gzfilebuf::open. out mode. setp" << std::endl;
             this->setp( M_buf, M_buf + M_buf_size );
             M_impl->open_mode_ = std::ios_base::out;
         }
+
         ret = this;
     }
 #endif
@@ -239,10 +242,12 @@ gzfilebuf::flushBuf()
          && pptr() )
     {
         int size = ( pptr() - pbase() ) * sizeof( char_type );
+
         if ( size == 0 )
         {
             ret = true;
         }
+
         if ( size > 0 )
         {
             if ( gzwrite( M_impl->file_, M_buf, size ) != 0 )
@@ -251,6 +256,7 @@ gzfilebuf::flushBuf()
                 ret = true;
             }
         }
+
         this->setp( M_buf, M_buf+ M_buf_size );
     }
 #endif
@@ -272,6 +278,7 @@ gzfilebuf::makeModeString( std::ios_base::openmode mode,
     // set I/O
     bool testi = static_cast< bool >( mode & std::ios_base::in );
     bool testo = static_cast< bool >( mode & std::ios_base::out );
+
     if ( ( testi && testo )
          || ( ! testi && ! testo ) )
     {
@@ -404,6 +411,7 @@ gzfilebuf::seekoff( std::streamoff off,
             M_remained_size = 0;
             this->setg( M_buf, M_buf, M_buf );
         }
+
         if ( way & std::ios_base::cur )
         {
             ret = gzseek( M_impl->file_, off, SEEK_CUR );
@@ -427,6 +435,7 @@ gzfilebuf::seekoff( std::streamoff off,
                 this->setp( M_buf, M_buf + M_buf_size );
             }
         }
+
         if ( way & std::ios_base::cur )
         {
             if ( off < 0 )
@@ -464,6 +473,7 @@ gzfilebuf::seekpos( std::streampos pos,
         M_remained_size = 0;
         this->setg( M_buf, M_buf, M_buf );
     }
+
     if ( ( M_impl->open_mode_ & std::ios_base::out )
          && ( mode & std::ios_base::out ) )
     {
@@ -558,6 +568,7 @@ gzfilebuf::underflow()
     {
         M_buf[0] = M_remained_char;
     }
+
     int read_size = gzread( M_impl->file_,
                             ( void* )( M_buf + M_remained_size ),
                             M_buf_size * sizeof( char_type ) - M_remained_size );
@@ -565,6 +576,7 @@ gzfilebuf::underflow()
     {
         return traits_type::eof();
     }
+
     int total_size = read_size + M_remained_size;
     this->setg( M_buf, M_buf, M_buf + total_size / sizeof( char_type ) );
     //std::cerr << "gzfilebuf::underflow. total_size=" << total_size
@@ -656,7 +668,7 @@ gzfilebuf::xsputn( gzfilebuf::char_type * s,
 
 */
 gzifstream::gzifstream()
-    : std::istream( static_cast< std::streambuf* >( 0 ) )
+    : std::istream( static_cast< std::streambuf * >( 0 ) )
     , M_file_buf()
 {
     this->init( &M_file_buf );
@@ -667,7 +679,7 @@ gzifstream::gzifstream()
 
 */
 gzifstream::gzifstream( const char * path )
-    : std::istream( static_cast< std::streambuf* >( 0 ) )
+    : std::istream( static_cast< std::streambuf * >( 0 ) )
     , M_file_buf()
 {
     this->init( &M_file_buf );
