@@ -30,20 +30,21 @@
 /////////////////////////////////////////////////////////////////////
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
-#include <cassert>
-#include <cmath>
-#include <iostream>
-#include <sstream>
-
-#include <rcsc/rcg/util.h>
-#include <rcsc/rcg/types.h>
+#include "server_param.h"
 
 #include "param_map.h"
 #include "rcss_param_parser.h"
-#include "server_param.h"
+
+#include <rcsc/rcg/types.h>
+#include <rcsc/rcg/util.h>
+
+#include <sstream>
+#include <iostream>
+#include <cmath>
+#include <cassert>
 
 namespace rcsc {
 
@@ -607,240 +608,240 @@ void
 ServerParam::createMap()
 {
     M_param_map->add()
-        ( &M_goal_width, "goal_width" )
-        ( &M_inertia_moment, "inertia_moment" )
+        ( "goal_width", "", &M_goal_width )
+        ( "inertia_moment", "", &M_inertia_moment )
 
-        ( &M_player_size, "player_size" )
-        ( &M_player_decay, "player_decay" )
-        ( &M_player_rand, "player_rand" )
-        ( &M_player_weight, "player_weight" )
-        ( &M_player_speed_max, "player_speed_max" )
-        ( &M_player_accel_max, "player_accel_max" )
+        ( "player_size", "", &M_player_size )
+        ( "player_decay", "", &M_player_decay )
+        ( "player_rand", "", &M_player_rand )
+        ( "player_weight", "", &M_player_weight )
+        ( "player_speed_max", "", &M_player_speed_max )
+        ( "player_accel_max", "", &M_player_accel_max )
 
-        ( &M_stamina_max, "stamina_max" )
-        ( &M_stamina_inc_max, "stamina_inc_max" )
+        ( "stamina_max", "", &M_stamina_max )
+        ( "stamina_inc_max", "", &M_stamina_inc_max )
 
-        ( &M_recover_init, "recover_init" ) // not necessary
-        ( &M_recover_dec_thr, "recover_dec_thr" )
-        ( &M_recover_min, "recover_min" )
-        ( &M_recover_dec, "recover_dec" )
+        ( "recover_init", "", &M_recover_init ) // not necessary
+        ( "recover_dec_thr", "", &M_recover_dec_thr )
+        ( "recover_min", "", &M_recover_min )
+        ( "recover_dec", "", &M_recover_dec )
 
-        ( &M_effort_init, "effort_init" )
-        ( &M_effort_dec_thr, "effort_dec_thr" )
-        ( &M_effort_min, "effort_min" )
-        ( &M_effort_dec, "effort_dec" )
-        ( &M_effort_inc_thr, "effort_inc_thr" )
-        ( &M_effort_inc, "effort_inc" )
+        ( "effort_init", "", &M_effort_init )
+        ( "effort_dec_thr", "", &M_effort_dec_thr )
+        ( "effort_min", "", &M_effort_min )
+        ( "effort_dec", "", &M_effort_dec )
+        ( "effort_inc_thr", "", &M_effort_inc_thr )
+        ( "effort_inc", "",  &M_effort_inc )
 
-        ( &M_kick_rand, "kick_rand" )
-        ( &M_team_actuator_noise, "team_actuator_noise" )
-        ( &M_player_rand_factor_l, "prand_factor_l" )
-        ( &M_player_rand_factor_r, "prand_factor_r" )
-        ( &M_kick_rand_factor_l, "kick_rand_factor_l" )
-        ( &M_kick_rand_factor_r, "kick_rand_factor_r" )
+        ( "kick_rand", "", &M_kick_rand )
+        ( "team_actuator_noise", "", &M_team_actuator_noise )
+        ( "prand_factor_l", "", &M_player_rand_factor_l )
+        ( "prand_factor_r", "", &M_player_rand_factor_r )
+        ( "kick_rand_factor_l", "", &M_kick_rand_factor_l )
+        ( "kick_rand_factor_r", "", &M_kick_rand_factor_r )
 
-        ( &M_ball_size, "ball_size" )
-        ( &M_ball_decay, "ball_decay" )
-        ( &M_ball_rand, "ball_rand" )
-        ( &M_ball_weight, "ball_weight" )
-        ( &M_ball_speed_max, "ball_speed_max" )
-        ( &M_ball_accel_max, "ball_accel_max" )
+        ( "ball_size", "", &M_ball_size )
+        ( "ball_decay", "", &M_ball_decay )
+        ( "ball_rand", "", &M_ball_rand )
+        ( "ball_weight", "", &M_ball_weight )
+        ( "ball_speed_max", "", &M_ball_speed_max )
+        ( "ball_accel_max", "", &M_ball_accel_max )
 
-        ( &M_dash_power_rate, "dash_power_rate" )
-        ( &M_kick_power_rate, "kick_power_rate" )
-        ( &M_kickable_margin, "kickable_margin" )
-        ( &M_control_radius, "control_radius" )
-        ( &M_control_radius_width, "control_radius_width" ) // not needed
+        ( "dash_power_rate", "", &M_dash_power_rate )
+        ( "kick_power_rate", "", &M_kick_power_rate )
+        ( "kickable_margin", "", &M_kickable_margin )
+        ( "control_radius", "", &M_control_radius )
+        ( "control_radius_width", "", &M_control_radius_width ) // not needed
 
-        ( &M_max_power, "maxpower" )
-        ( &M_min_power, "minpower" )
-        ( &M_max_moment, "maxmoment" )
-        ( &M_min_moment, "minmoment" )
-        ( &M_max_neck_moment, "maxneckmoment" )
-        ( &M_min_neck_moment, "minneckmoment" )
-        ( &M_max_neck_angle, "maxneckang" )
-        ( &M_min_neck_angle, "minneckang" )
+        ( "maxpower", "", &M_max_power )
+        ( "minpower", "", &M_min_power )
+        ( "maxmoment", "", &M_max_moment )
+        ( "minmoment", "", &M_min_moment )
+        ( "maxneckmoment", "", &M_max_neck_moment )
+        ( "minneckmoment", "", &M_min_neck_moment )
+        ( "maxneckang", "", &M_max_neck_angle )
+        ( "minneckang", "", &M_min_neck_angle )
 
-        ( &M_visible_angle, "visible_angle" )
-        ( &M_visible_distance, "visible_distance" )
+        ( "visible_angle", "", &M_visible_angle )
+        ( "visible_distance", "", &M_visible_distance )
 
-        ( &M_wind_dir, "wind_dir" )
-        ( &M_wind_force, "wind_force" )
-        ( &M_wind_angle, "wind_ang" )
-        ( &M_wind_rand, "wind_rand" )
+        ( "wind_dir", "", &M_wind_dir )
+        ( "wind_force", "", &M_wind_force )
+        ( "wind_ang", "", &M_wind_angle )
+        ( "wind_rand", "", &M_wind_rand )
 
-        ( &M_kickable_area, "kickable_area" ) // not needed
+        ( "kickable_area", "", &M_kickable_area ) // not needed
 
-        ( &M_catch_area_l, "catchable_area_l" )
-        ( &M_catch_area_w, "catchable_area_w" )
-        ( &M_catch_probability, "catch_probability" )
-        ( &M_goalie_max_moves, "goalie_max_moves" )
+        ( "catchable_area_l", "", &M_catch_area_l )
+        ( "catchable_area_w", "", &M_catch_area_w )
+        ( "catch_probability", "", &M_catch_probability )
+        ( "goalie_max_moves", "", &M_goalie_max_moves )
 
-        ( &M_corner_kick_margin, "ckick_margin" )
-        ( &M_offside_active_area_size, "offside_active_area_size" )
+        ( "ckick_margin", "", &M_corner_kick_margin )
+        ( "offside_active_area_size", "", &M_offside_active_area_size )
 
-        ( BoolSwitch( &M_wind_none ), "wind_none" )
-        ( BoolSwitch( &M_use_wind_random ), "wind_random" )
+        ( "wind_none", "", BoolSwitch( &M_wind_none ) )
+        ( "wind_random", "", BoolSwitch( &M_use_wind_random ) )
 
-        ( &M_coach_say_count_max, "say_coach_cnt_max" )
-        ( &M_coach_say_msg_size, "say_coach_msg_size" )
+        ( "say_coach_cnt_max", "", &M_coach_say_count_max )
+        ( "say_coach_msg_size", "", &M_coach_say_msg_size )
 
-        ( &M_clang_win_size, "clang_win_size" )
-        ( &M_clang_define_win, "clang_define_win" )
-        ( &M_clang_meta_win, "clang_meta_win" )
-        ( &M_clang_advice_win, "clang_advice_win" )
-        ( &M_clang_info_win, "clang_info_win" )
-        ( &M_clang_mess_delay, "clang_mess_delay" )
-        ( &M_clang_mess_per_cycle, "clang_mess_per_cycle" )
+        ( "clang_win_size", "", &M_clang_win_size )
+        ( "clang_define_win", "", &M_clang_define_win )
+        ( "clang_meta_win", "", &M_clang_meta_win )
+        ( "clang_advice_win", "", &M_clang_advice_win )
+        ( "clang_info_win", "", &M_clang_info_win )
+        ( "clang_mess_delay", "", &M_clang_mess_delay )
+        ( "clang_mess_per_cycle", "", &M_clang_mess_per_cycle )
 
-        ( &M_half_time, "half_time" )
-        ( &M_simulator_step, "simulator_step" )
-        ( &M_send_step, "send_step" )
-        ( &M_recv_step, "recv_step" )
-        ( &M_sense_body_step, "sense_body_step" )
-        ( &M_lcm_step, "lcm_step" )
+        ( "half_time", "", &M_half_time )
+        ( "simulator_step", "", &M_simulator_step )
+        ( "send_step", "", &M_send_step )
+        ( "recv_step", "", &M_recv_step )
+        ( "sense_body_step", "", &M_sense_body_step )
+        ( "lcm_step", "", &M_lcm_step )
 
-        ( &M_player_say_msg_size, "say_msg_size" )
-        ( &M_player_hear_max, "hear_max" )
-        ( &M_player_hear_inc, "hear_inc" )
-        ( &M_player_hear_decay, "hear_decay" )
+        ( "say_msg_size", "", &M_player_say_msg_size )
+        ( "hear_max", "", &M_player_hear_max )
+        ( "hear_inc", "", &M_player_hear_inc )
+        ( "hear_decay", "", &M_player_hear_decay )
 
-        ( &M_catch_ban_cycle, "catch_ban_cycle" )
+        ( "catch_ban_cycle", "", &M_catch_ban_cycle )
 
-        ( &M_slow_down_factor, "slow_down_factor" )
+        ( "slow_down_factor", "", &M_slow_down_factor )
 
-        ( &M_use_offside, "use_offside" )
-        ( &M_kickoff_offside, "forbid_kick_off_offside" )
-        ( &M_offside_kick_margin, "offside_kick_margin" )
+        ( "use_offside", "", &M_use_offside )
+        ( "forbid_kick_off_offside", "", &M_kickoff_offside )
+        ( "offside_kick_margin", "", &M_offside_kick_margin )
 
-        ( &M_audio_cut_dist, "audio_cut_dist" )
+        ( "audio_cut_dist", "", &M_audio_cut_dist )
 
-        ( &M_dist_quantize_step, "quantize_step" )
-        ( &M_landmark_dist_quantize_step, "quantize_step_l" )
-        ( &M_dir_quantize_step, "quantize_step_dir" )
-        ( &M_dist_quantize_step_l, "quantize_step_dist_team_l" )
-        ( &M_dist_quantize_step_r, "quantize_step_dist_team_r" )
-        ( &M_landmark_dist_quantize_step_l, "quantize_step_dist_l_team_l" )
-        ( &M_landmark_dist_quantize_step_r, "quantize_step_dist_l_team_r" )
-        ( &M_dir_quantize_step_l, "quantize_step_dir_team_l" )
-        ( &M_dir_quantize_step_r, "quantize_step_dir_team_r" )
+        ( "quantize_step", "", &M_dist_quantize_step )
+        ( "quantize_step_l", "", &M_landmark_dist_quantize_step )
+        ( "quantize_step_dir", "", &M_dir_quantize_step )
+        ( "quantize_step_dist_team_l", "", &M_dist_quantize_step_l )
+        ( "quantize_step_dist_team_r", "", &M_dist_quantize_step_r )
+        ( "quantize_step_dist_l_team_l", "", &M_landmark_dist_quantize_step_l )
+        ( "quantize_step_dist_l_team_r", "", &M_landmark_dist_quantize_step_r )
+        ( "quantize_step_dir_team_l", "", &M_dir_quantize_step_l )
+        ( "quantize_step_dir_team_r", "", &M_dir_quantize_step_r )
 
-        ( BoolSwitch( &M_coach_mode ), "coach" )
-        ( BoolSwitch( &M_coach_with_referee_mode ), "coach_w_referee" )
-        ( BoolSwitch( &M_use_old_coach_hear ), "old_coach_hear" )
+        ( "coach", "", BoolSwitch( &M_coach_mode ) )
+        ( "coach_w_referee", "", BoolSwitch( &M_coach_with_referee_mode ) )
+        ( "old_coach_hear", "", BoolSwitch( &M_use_old_coach_hear ) )
 
-        ( &M_slowness_on_top_for_left_team, "slowness_on_top_for_left_team" )
-        ( &M_slowness_on_top_for_right_team,"slowness_on_top_for_right_team" )
+        ( "slowness_on_top_for_left_team", "", &M_slowness_on_top_for_left_team )
+        ( "slowness_on_top_for_right_team", "", &M_slowness_on_top_for_right_team )
 
-        ( &M_start_goal_l, "start_goal_l" )
-        ( &M_start_goal_r, "start_goal_r" )
+        ( "start_goal_l", "", &M_start_goal_l )
+        ( "start_goal_r", "", &M_start_goal_r )
 
-        ( &M_fullstate_l, "fullstate_l" )
-        ( &M_fullstate_r, "fullstate_r" )
+        ( "fullstate_l", "", &M_fullstate_l )
+        ( "fullstate_r", "", &M_fullstate_r )
 
-        ( &M_drop_ball_time, "drop_ball_time" )
+        ( "drop_ball_time", "", &M_drop_ball_time )
 
-        ( &M_synch_mode, "synch_mode" )
-        ( &M_synch_offset, "synch_offset" )
-        ( &M_synch_micro_sleep, "synch_micro_sleep" )
+        ( "synch_mode", "", &M_synch_mode )
+        ( "synch_offset", "", &M_synch_offset )
+        ( "synch_micro_sleep", "", &M_synch_micro_sleep )
 
-        ( &M_point_to_ban, "point_to_ban" )
-        ( &M_point_to_duration, "point_to_duration" )
+        ( "point_to_ban", "", &M_point_to_ban )
+        ( "point_to_duration", "", &M_point_to_duration )
 
         // not defined in server_params_t
-        ( &M_player_port, "port" )
-        ( &M_trainer_port, "coach_port" )
-        ( &M_online_coach_port, "olcoach_port" )
+        ( "port", "", &M_player_port )
+        ( "coach_port", "", &M_trainer_port )
+        ( "olcoach_port", "", &M_online_coach_port )
 
-        ( &M_verbose_mode, "verbose" )
+        ( "verbose", "", &M_verbose_mode )
 
-        ( &M_coach_send_vi_step, "send_vi_step" )
+        ( "send_vi_step", "", &M_coach_send_vi_step )
 
-        ( &M_replay_file, "replay" ) // unused after rcsserver-9+
-        ( &M_landmark_file, "landmark_file" )
+        ( "replay", "", &M_replay_file ) // unused after rcsserver-9+
+        ( "landmark_file", "", &M_landmark_file )
 
-        ( &M_send_comms, "send_comms" )
+        ( "send_comms", "", &M_send_comms )
 
         // logging params are not used in normal client
-        ( &M_text_logging,"text_logging" )
-        ( &M_game_logging, "game_logging" )
-        ( &M_game_log_version, "game_log_version" )
-        ( &M_text_log_dir, "text_log_dir" )
-        ( &M_game_log_dir, "game_log_dir" )
-        ( &M_text_log_fixed_name, "text_log_fixed_name" )
-        ( &M_game_log_fixed_name, "game_log_fixed_name" )
-        ( &M_use_text_log_fixed, "text_log_fixed" )
-        ( &M_use_game_log_fixed, "game_log_fixed" )
-        ( &M_use_text_log_dated, "text_log_dated" )
-        ( &M_use_game_log_dated, "game_log_dated" )
-        ( &M_log_date_format, "log_date_format" )
-        ( &M_log_times, "log_times" )
-        ( &M_record_message, "record_messages" )
-        ( &M_text_log_compression, "text_log_compression" )
-        ( &M_game_log_compression, "game_log_compression" )
-        ( &M_use_profile, "profile" )
+        ( "text_logging", "", &M_text_logging )
+        ( "game_logging", "", &M_game_logging )
+        ( "game_log_version", "", &M_game_log_version )
+        ( "text_log_dir", "", &M_text_log_dir )
+        ( "game_log_dir", "", &M_game_log_dir )
+        ( "text_log_fixed_name", "", &M_text_log_fixed_name )
+        ( "game_log_fixed_name", "", &M_game_log_fixed_name )
+        ( "text_log_fixed", "", &M_use_text_log_fixed )
+        ( "game_log_fixed", "", &M_use_game_log_fixed )
+        ( "text_log_dated", "", &M_use_text_log_dated )
+        ( "game_log_dated", "", &M_use_game_log_dated )
+        ( "log_date_format", "", &M_log_date_format )
+        ( "log_times", "", &M_log_times )
+        ( "record_messages", "", &M_record_message )
+        ( "text_log_compression", "", &M_text_log_compression )
+        ( "game_log_compression", "", &M_game_log_compression )
+        ( "profile", "", &M_use_profile )
 
 
-        ( &M_tackle_dist, "tackle_dist" )
-        ( &M_tackle_back_dist, "tackle_back_dist" )
-        ( &M_tackle_width, "tackle_width" )
-        ( &M_tackle_exponent, "tackle_exponent" )
-        ( &M_tackle_cycles, "tackle_cycles" )
-        ( &M_tackle_power_rate, "tackle_power_rate" )
+        ( "tackle_dist", "", &M_tackle_dist )
+        ( "tackle_back_dist", "", &M_tackle_back_dist )
+        ( "tackle_width", "", &M_tackle_width )
+        ( "tackle_exponent", "", &M_tackle_exponent )
+        ( "tackle_cycles", "", &M_tackle_cycles )
+        ( "tackle_power_rate", "", &M_tackle_power_rate )
 
-        ( &M_freeform_wait_period, "freeform_wait_period" )
-        ( &M_freeform_send_period, "freeform_send_period" )
+        ( "freeform_wait_period", "", &M_freeform_wait_period )
+        ( "freeform_send_period", "", &M_freeform_send_period )
 
-        ( &M_free_kick_faults, "free_kick_faults" )
-        ( &M_back_passes, "back_passes" )
+        ( "free_kick_faults", "", &M_free_kick_faults )
+        ( "back_passes", "", &M_back_passes )
 
-        ( &M_proper_goal_kicks, "proper_goal_kicks" )
-        ( &M_stopped_ball_vel, "stopped_ball_vel" )
-        ( &M_max_goal_kicks, "max_goal_kicks" )
+        ( "proper_goal_kicks", "", &M_proper_goal_kicks )
+        ( "stopped_ball_vel", "", &M_stopped_ball_vel )
+        ( "max_goal_kicks", "", &M_max_goal_kicks )
 
-        ( &M_clang_del_win, "clang_del_win" )
-        ( &M_clang_rule_win, "clang_rule_win" )
+        ( "clang_del_win", "", &M_clang_del_win )
+        ( "clang_rule_win", "", &M_clang_rule_win )
 
-        ( &M_auto_mode, "auto_mode" )
-        ( &M_kick_off_wait, "kick_off_wait" )
-        ( &M_connect_wait, "connect_wait" )
-        ( &M_game_over_wait, "game_over_wait" )
+        ( "auto_mode", "", &M_auto_mode )
+        ( "kick_off_wait", "", &M_kick_off_wait )
+        ( "connect_wait", "", &M_connect_wait )
+        ( "game_over_wait", "", &M_game_over_wait )
 
         // not necessary
-        ( &M_team_l_start, "team_l_start" )
-        ( &M_team_r_start, "team_r_start" )
+        ( "team_l_start", "", &M_team_l_start )
+        ( "team_r_start", "", &M_team_r_start )
 
 
-        ( &M_keepaway_mode, "keepaway" )
-        ( &M_ka_length, "keepaway_length" )
-        ( &M_ka_width, "keepaway_width" )
+        ( "keepaway", "", &M_keepaway_mode )
+        ( "keepaway_length", "", &M_ka_length )
+        ( "keepaway_width", "", &M_ka_width )
 
         // logging params are not used in normal client
-        ( &M_kaway_logging, "keepaway_logging" )
-        ( &M_kaway_log_dir, "keepaway_log_dir" )
-        ( &M_kaway_log_fixed_name, "keepaway_log_fixed_name" )
-        ( &M_kaway_log_fixed, "keepaway_log_fixed" )
-        ( &M_kaway_log_dated, "keepaway_log_dated" )
+        ( "keepaway_logging", "", &M_kaway_logging )
+        ( "keepaway_log_dir", "", &M_kaway_log_dir )
+        ( "keepaway_log_fixed_name", "", &M_kaway_log_fixed_name )
+        ( "keepaway_log_fixed", "", &M_kaway_log_fixed )
+        ( "keepaway_log_dated", "", &M_kaway_log_dated )
 
-        ( &M_kaway_start, "keepaway_start" )
+        ( "keepaway_start", "", &M_kaway_start )
 
-        ( &M_nr_normal_halfs, "nr_normal_halfs" )
-        ( &M_nr_extra_halfs, "nr_extra_halfs" )
-        ( &M_penalty_shoot_outs, "penalty_shoot_outs" )
+        ( "nr_normal_halfs", "", &M_nr_normal_halfs )
+        ( "nr_extra_halfs", "", &M_nr_extra_halfs )
+        ( "penalty_shoot_outs", "", &M_penalty_shoot_outs )
 
-        ( &M_pen_before_setup_wait, "pen_before_setup_wait" )
-        ( &M_pen_setup_wait, "pen_setup_wait" )
-        ( &M_pen_ready_wait, "pen_ready_wait" )
-        ( &M_pen_taken_wait, "pen_taken_wait" )
-        ( &M_pen_nr_kicks, "pen_nr_kicks" )
-        ( &M_pen_max_extra_kicks, "pen_max_extra_kicks" )
-        ( &M_pen_dist_x, "pen_dist_x" )
-        ( &M_pen_random_winner, "pen_random_winner" )
-        ( &M_pen_max_goalie_dist_x, "pen_max_goalie_dist_x" )
-        ( &M_pen_allow_mult_kicks, "pen_allow_mult_kicks" )
-        ( &M_pen_coach_moves_players, "pen_coach_moves_players" )
+        ( "pen_before_setup_wait", "", &M_pen_before_setup_wait )
+        ( "pen_setup_wait", "", &M_pen_setup_wait )
+        ( "pen_ready_wait", "", &M_pen_ready_wait )
+        ( "pen_taken_wait", "", &M_pen_taken_wait )
+        ( "pen_nr_kicks", "", &M_pen_nr_kicks )
+        ( "pen_max_extra_kicks", "", &M_pen_max_extra_kicks )
+        ( "pen_dist_x", "", &M_pen_dist_x )
+        ( "pen_random_winner", "", &M_pen_random_winner )
+        ( "pen_max_goalie_dist_x", "", &M_pen_max_goalie_dist_x )
+        ( "pen_allow_mult_kicks", "", &M_pen_allow_mult_kicks )
+        ( "pen_coach_moves_players", "", &M_pen_coach_moves_players )
 
-        ( &M_module_dir, "module_dir" );
+        ( "module_dir", "", &M_module_dir );
 }
 
 /*-------------------------------------------------------------------*/
