@@ -30,21 +30,20 @@
 /////////////////////////////////////////////////////////////////////
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
+#include "action_effector.h"
+
+#include "player_agent.h"
+#include "world_model.h"
+#include "logger.h"
+#include "body_sensor.h"
+#include "player_command.h"
+
 #include <rcsc/math_util.h>
 #include <rcsc/param/server_param.h>
 
-#include "player_command.h"
-
-#include "logger.h"
-#include "body_sensor.h"
-#include "world_model.h"
-#include "player_agent.h"
-
-#include "action_effector.h"
-
 namespace rcsc {
 
 /*-------------------------------------------------------------------*/
@@ -60,7 +59,7 @@ ActionEffector::ActionEffector( const WorldModel & world )
     , M_command_pointto( static_cast< PlayerPointtoCommand * >( 0 ) )
     , M_command_attentionto( static_cast< PlayerAttentiontoCommand * >( 0 ) )
     , M_last_action_time( 0, 0 )
-    , M_last_base_command( PlayerCommand::ILLEGAL )
+    , M_last_body_command_type( PlayerCommand::ILLEGAL )
     , M_done_turn_neck( false )
     , M_kick_accel( 0.0, 0.0 )
     , M_kick_accel_error( 0.0, 0.0 )
@@ -140,7 +139,7 @@ ActionEffector::reset()
     //             and before action decision.
     //  Do NOT update change_viwe info for adjustment of see arrival timing
 
-    M_last_base_command = PlayerCommand::ILLEGAL;
+    M_last_body_command_type = PlayerCommand::ILLEGAL;
     M_done_turn_neck = false;
     M_say_message = "";
 
@@ -205,7 +204,7 @@ ActionEffector::checkCommandCount( const BodySensor & sense )
                       "lost kick? sense= %d internal= %d",
                       sense.kickCount(),
                       M_command_counter[PlayerCommand::KICK] );
-        M_last_base_command = PlayerCommand::ILLEGAL;
+        M_last_body_command_type = PlayerCommand::ILLEGAL;
         M_kick_accel.assign( 0.0, 0.0 );
         M_kick_accel_error.assign( 0.0, 0.0 );
         M_command_counter[PlayerCommand::KICK] = sense.kickCount();
@@ -222,7 +221,7 @@ ActionEffector::checkCommandCount( const BodySensor & sense )
                       "lost turn? sense= %d internal= %d",
                       sense.turnCount(),
                       M_command_counter[PlayerCommand::TURN] );
-        M_last_base_command = PlayerCommand::ILLEGAL;
+        M_last_body_command_type = PlayerCommand::ILLEGAL;
         M_turn_actual = 0.0;
         M_turn_error = 0.0;
         M_command_counter[PlayerCommand::TURN] = sense.turnCount();
@@ -239,7 +238,7 @@ ActionEffector::checkCommandCount( const BodySensor & sense )
                       "lost dash? sense= %d internal= %d",
                       sense.dashCount(),
                       M_command_counter[PlayerCommand::DASH] );
-        M_last_base_command = PlayerCommand::ILLEGAL;
+        M_last_body_command_type = PlayerCommand::ILLEGAL;
         M_dash_accel.assign( 0.0, 0.0 );
         //M_dash_accel_error.assign( 0.0, 0.0 );
         M_dash_power = 0.0;
@@ -257,8 +256,8 @@ ActionEffector::checkCommandCount( const BodySensor & sense )
                       "lost move? sense= %d internal= %d",
                       sense.moveCount(),
                       M_command_counter[PlayerCommand::MOVE] );
-        M_last_base_command = PlayerCommand::ILLEGAL;
-        M_move_pos.assign( Vector2D::INVALID );
+        M_last_body_command_type = PlayerCommand::ILLEGAL;
+        M_move_pos.invalidate();
         M_command_counter[PlayerCommand::MOVE] = sense.moveCount();
     }
 
@@ -273,7 +272,7 @@ ActionEffector::checkCommandCount( const BodySensor & sense )
                       "lost catch? sense= %d internal= %d",
                       sense.catchCount(),
                       M_command_counter[PlayerCommand::CATCH] );
-        M_last_base_command = PlayerCommand::ILLEGAL;
+        M_last_body_command_type = PlayerCommand::ILLEGAL;
         M_catch_time.assign( 0, 0 );
         M_command_counter[PlayerCommand::CATCH] = sense.catchCount();
     }
@@ -289,7 +288,7 @@ ActionEffector::checkCommandCount( const BodySensor & sense )
                       "lost tackle? sense= %d internal= %d",
                       sense.tackleCount(),
                       M_command_counter[PlayerCommand::TACKLE] );
-        M_last_base_command = PlayerCommand::ILLEGAL;
+        M_last_body_command_type = PlayerCommand::ILLEGAL;
         M_tackle_power = 0.0;
         M_tackle_dir = 0.0;
         M_command_counter[PlayerCommand::TACKLE] = sense.tackleCount();
@@ -379,8 +378,8 @@ ActionEffector::makeCommand( std::ostream & to )
 
     if ( M_command_body )
     {
-        M_last_base_command = M_command_body->type();
-        if ( M_last_base_command == PlayerCommand::CATCH )
+        M_last_body_command_type = M_command_body->type();
+        if ( M_last_body_command_type == PlayerCommand::CATCH )
         {
             M_catch_time = M_world.time();
         }
@@ -1141,7 +1140,7 @@ ActionEffector::setPointtoOff()
     M_command_pointto = new PlayerPointtoCommand();
 
     // set estimated command effect
-    M_pointto_pos.assign( Vector2D::INVALID );
+    M_pointto_pos.invalidate();
 }
 
 /*-------------------------------------------------------------------*/
@@ -1251,7 +1250,7 @@ ActionEffector::queuedNextBallPos() const
 {
     if ( ! M_world.ball().posValid() )
     {
-        return Vector2D( Vector2D::INVALID );
+        return Vector2D::INVALIDATED;
     }
 
     Vector2D vel( 0.0, 0.0 ), accel( 0.0, 0.0 );
@@ -1318,7 +1317,7 @@ ActionEffector::queuedNextViewWidth() const
 {
     if ( M_command_change_view )
     {
-        return M_command_change_view->getWidth();
+        return M_command_change_view->width();
     }
 
     return M_world.self().viewWidth();
