@@ -30,20 +30,19 @@
 /////////////////////////////////////////////////////////////////////
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
-#include <iostream>
-
-#include <rcsc/game_mode.h>
-#include <rcsc/param/server_param.h>
-
-#include "logger.h"
-#include "self_object.h"
+#include "ball_object.h"
 #include "action_effector.h"
+#include "self_object.h"
+#include "logger.h"
 #include "player_command.h"
 
-#include "ball_object.h"
+#include <rcsc/param/server_param.h>
+#include <rcsc/game_mode.h>
+
+#include <iostream>
 
 namespace rcsc {
 
@@ -61,14 +60,14 @@ BallObject::BallObject()
     , M_pos( 0.0, 0.0 )
     , M_pos_error( 0.0, 0.0 )
     , M_pos_count( 1000 )
-    , M_rpos( Vector2D::INVALID )
+    , M_rpos( Vector2D::INVALIDATED )
     , M_rpos_error( 0.0, 0.0 )
     , M_rpos_count( 1000 )
-    , M_rpos_prev( Vector2D::INVALID )
+    , M_rpos_prev( Vector2D::INVALIDATED )
     , M_vel( 0.0, 0.0 )
     , M_vel_error( 0.0, 0.0 )
     , M_vel_count( 1000 )
-    , M_last_seen_pos( Vector2D::INVALID )
+    , M_last_seen_pos( Vector2D::INVALIDATED )
     , M_lost_count( 0 )
     , M_heard_time( 0, 0 )
     , M_heard_pos( 0.0, 0.0 )
@@ -128,7 +127,7 @@ BallObject::update( const ActionEffector & act,
         /////////////////////////////////////////////////////////////
         // kicked in last cycle
         // get info from stored action param
-        if ( act.getLastCommandType() == PlayerCommand::KICK )
+        if ( act.lastBodyCommandType() == PlayerCommand::KICK )
         {
             act.getKickInfo( &accel, &accel_err );
             dlog.addText( Logger::WORLD,
@@ -264,7 +263,7 @@ BallObject::updateByFullstate( const Vector2D & pos,
     M_vel = vel;
     M_vel_error.assign( 0.0, 0.0 );
     M_vel_count = 0;
-    
+
     M_last_seen_pos = pos;
     M_lost_count = 0;
 }
@@ -442,13 +441,13 @@ BallObject::updateSelfRelated( const SelfObject & self )
     {
         // update rpos
         if ( M_rpos_prev.valid()
-             && self.getLastMove().valid() )
+             && self.lastMove().valid() )
         {
             // M_rpos_prev is updated in update()
             M_rpos
                 = M_rpos_prev
                 + ( M_vel / ServerParam::i().ballDecay() )
-                - self.getLastMove();
+                - self.lastMove();
             M_rpos_error += M_vel_error;
             M_rpos_error += ( self.velError() / self.playerType().playerDecay() );
         }
