@@ -30,14 +30,14 @@
 /////////////////////////////////////////////////////////////////////
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
+#include "body_sensor.h"
+
 #include <string>
 #include <cstdio>
 
-#include "body_sensor.h"
-
 namespace rcsc {
 
 /*-------------------------------------------------------------------*/
