@@ -30,12 +30,11 @@
 /////////////////////////////////////////////////////////////////////
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
 #include "fullstate_sensor.h"
 #include "logger.h"
-//#include "world_model.h"
 
 #include <algorithm>
 #include <iterator>
