@@ -32,12 +32,12 @@
 #ifndef RCSC_PLAYER_FULLSTATE_SENSOR_H
 #define RCSC_PLAYER_FULLSTATE_SENSOR_H
 
-#include <iostream>
-#include <vector>
-
-#include <rcsc/types.h>
-#include <rcsc/game_time.h>
 #include <rcsc/geom/vector_2d.h>
+#include <rcsc/game_time.h>
+#include <rcsc/types.h>
+
+#include <vector>
+#include <iostream>
 
 namespace rcsc {
 
@@ -88,7 +88,7 @@ public:
             , unum_( -1 )
             , goalie_( false )
             , type_( 0 )
-            , pos_( Vector2D::INVALID )
+            , pos_( Vector2D::INVALIDATED )
             , vel_( 0.0, 0.0 )
             , body_( 0.0 )
             , neck_( 0.0 )
