@@ -32,8 +32,8 @@
 #ifndef RCSC_PLAYER_INTERCEPT_TABLE_H
 #define RCSC_PLAYER_INTERCEPT_TABLE_H
 
-#include <vector>
 #include <rcsc/geom/vector_2d.h>
+#include <vector>
 
 namespace rcsc {
 
@@ -56,7 +56,7 @@ private:
     Mode M_mode; //!< interception mode, NORMAL or EXHAUST
     int M_turn_cycle; //!< estimated turn cycles
     int M_dash_cycle; //!< estimated dash cycles
-    double M_power; //!< dash power to be used
+    double M_dash_power; //!< dash power to be used
 
     //! not used
     InterceptInfo();
@@ -68,11 +68,11 @@ public:
     InterceptInfo( const Mode mode,
                    const int turn_cycle,
                    const int dash_cycle,
-                   const double & power )
+                   const double & dash_power )
         : M_mode( mode )
         , M_turn_cycle( turn_cycle )
         , M_dash_cycle( dash_cycle )
-        , M_power( power )
+        , M_dash_power( dash_power )
       { }
 
     /*!
@@ -88,7 +88,7 @@ public:
       \brief get estimated total turn cycles
       \return the number of turn cycles
     */
-    int getTurnCycle() const
+    int turnCycle() const
       {
           return M_turn_cycle;
       }
@@ -97,7 +97,7 @@ public:
       \brief get estimated total dash cycles
       \return the number of dash cycles
     */
-    int getDashCycle() const
+    int dashCycle() const
       {
           return M_dash_cycle;
       }
@@ -106,9 +106,9 @@ public:
       \brief get esitimated total cycle to reach
       \return the number of total cycles
     */
-    int getReachCycle() const
+    int reachCycle() const
       {
-          return getTurnCycle() + getDashCycle();
+          return turnCycle() + dashCycle();
       }
 
     /*!
@@ -116,9 +116,9 @@ public:
       \return dash power to be used
     */
     const
-    double & getPower() const
+    double & dashPower() const
       {
-          return M_power;
+          return M_dash_power;
       }
 };
 
@@ -185,7 +185,7 @@ public:
       \brief get minimal ball gettable cycle for self without stamina exaust
       \return cycle value to get the ball
     */
-    int getSelfReachCycle() const
+    int selfReachCycle() const
       {
           return M_self_reach_cycle;
       }
@@ -194,7 +194,7 @@ public:
       \brief get minimal ball gettable cycle for self with stamina exaust
       \return cycle value to get the ball
     */
-    int getSelfExhaustReachCycle() const
+    int selfExhaustReachCycle() const
       {
           return M_self_exhaust_reach_cycle;
       }
@@ -203,7 +203,7 @@ public:
       \brief get minimal ball gettable cycle for teammate
       \return cycle value to get the ball
     */
-    int getTeammateReachCycle() const
+    int teammateReachCycle() const
       {
           return M_teammate_reach_cycle;
       }
@@ -212,7 +212,7 @@ public:
       \brief get minimal ball gettable cycle for opponent
       \return cycle value to get the ball
     */
-    int getOpponentReachCycle() const
+    int opponentReachCycle() const
       {
           return M_opponent_reach_cycle;
       }
@@ -223,7 +223,7 @@ public:
       if not exist such a player, return NULL
     */
     const
-    PlayerObject * getFastestTeammate() const
+    PlayerObject * fastestTeammate() const
       {
           return M_fastest_teammate;
       }
@@ -234,7 +234,7 @@ public:
       if not exist such a player, return NULL
     */
     const
-    PlayerObject * getFastestOpponent() const
+    PlayerObject * fastestOpponent() const
       {
           return M_fastest_opponent;
       }
@@ -244,7 +244,7 @@ public:
       \return const reference to the interception info container
     */
     const
-    std::vector< InterceptInfo > & getSelfCache() const
+    std::vector< InterceptInfo > & selfCache() const
       {
           return M_self_cache;
       }
@@ -253,7 +253,7 @@ public:
       \brief get ball gettable point for self
       \return ball gettaable point
     */
-    Vector2D getSelfInterceptPoint() const;
+    Vector2D selfInterceptPoint() const;
 
     /*!
       \brief check if self is the fastest ball bettable player
