@@ -32,11 +32,11 @@
 #ifndef RCSC_PLAYER_LOCALIZER_H
 #define RCSC_PLAYER_LOCALIZER_H
 
-#include <boost/scoped_ptr.hpp>
-
-#include <rcsc/types.h>
-#include <rcsc/geom/vector_2d.h>
 #include <rcsc/player/visual_sensor.h>
+#include <rcsc/geom/vector_2d.h>
+#include <rcsc/types.h>
+
+#include <boost/scoped_ptr.hpp>
 
 namespace rcsc {
 
@@ -71,9 +71,9 @@ public:
         PlayerT()
             : unum_( -1 )
             , goalie_( false )
-            , pos_( Vector2D::INVALID )
-            , rpos_( Vector2D::INVALID )
-            , vel_( Vector2D::INVALID )
+            , pos_( Vector2D::INVALIDATED )
+            , rpos_( Vector2D::INVALIDATED )
+            , vel_( Vector2D::INVALIDATED )
             , body_( 0.0 )
             , face_( 0.0 )
             , has_face_( false )
@@ -87,8 +87,8 @@ public:
         */
         void reset()
           {
-              pos_.assign( Vector2D::INVALID );
-              rpos_.assign( Vector2D::INVALID );
+              pos_.invalidate();
+              rpos_.invalidate();
               unum_ = -1;
               has_face_ = pointto_ = tackle_ = false;
           }
