@@ -30,23 +30,10 @@
 /////////////////////////////////////////////////////////////////////
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
-#include <cstdio>
-#include <cstring>
-#include <sstream>
-#include <algorithm>
-#include <iterator>
-
-#include <rcsc/math_util.h>
-#include <rcsc/game_mode.h>
-#include <rcsc/param/param_map.h>
-#include <rcsc/param/cmd_line_parser.h>
-#include <rcsc/param/conf_file_parser.h>
-#include <rcsc/param/player_param.h>
-#include <rcsc/param/player_type.h>
-#include <rcsc/param/server_param.h>
+#include "player_agent.h"
 
 #include "body_sensor.h"
 #include "visual_sensor.h"
@@ -59,7 +46,19 @@
 #include "soccer_action.h"
 #include "soccer_intention.h"
 
-#include "player_agent.h"
+#include <rcsc/param/param_map.h>
+#include <rcsc/param/cmd_line_parser.h>
+#include <rcsc/param/conf_file_parser.h>
+#include <rcsc/param/player_param.h>
+#include <rcsc/param/player_type.h>
+#include <rcsc/param/server_param.h>
+#include <rcsc/math_util.h>
+#include <rcsc/game_time.h>
+#include <rcsc/game_mode.h>
+
+#include <sstream>
+#include <cstdio>
+#include <cstring>
 
 //#define PROFILE_SEE
 
@@ -325,11 +324,11 @@ PlayerAgentImpl::isDecisionTiming( const long & msec_from_sense ) const
     }
 
     if ( see_state_.isSynch()
-         && see_state_.getCyclesTillNextSee() > 0 )
+         && see_state_.cyclesTillNextSee() > 0 )
     {
         dlog.addText( Logger::SYSTEM,
                       "estimated cycles till next see ----- %d",
-                      see_state_.getCyclesTillNextSee() );
+                      see_state_.cyclesTillNextSee() );
         return true;
     }
 
@@ -469,23 +468,20 @@ PlayerAgent::seeTimeStamp() const
 
 */
 bool
-PlayerAgent::doInit( const int argc,
-                     const char * const * argv )
+PlayerAgent::doInit( CmdLineParser & cmd_parser )
 {
     bool help = false;
     std::string player_config_file;
 
     ParamMap system_param_map( "System options" );
     system_param_map.add()
-        ( BoolSwitch( &help ), "help" , "", "print help message.")
-        ( &player_config_file, "player-config", "", "specifies player config file." );
+        ( "help" , "", BoolSwitch( &help ), "print help message.")
+        ( "player-config", "", &player_config_file, "specifies player config file." );
 
     ParamMap player_param_map( "Player options" );
     M_config.createParamMap( player_param_map );
 
 
-    CmdLineParser cmd_parser( argc, argv );
-
     // analyze command line for system options.
     cmd_parser.parse( system_param_map );
     if ( help )
@@ -506,14 +502,12 @@ PlayerAgent::doInit( const int argc,
     // analyze command line for player options.
     cmd_parser.parse( player_param_map );
 
-    if ( ! cmd_parser.invalidOptions().empty() )
-    {
-        std::cerr << "player: ***WARNING*** detected invalid options: ";
-        std::copy( cmd_parser.invalidOptions().begin(),
-                   cmd_parser.invalidOptions().end(),
-                   std::ostream_iterator< std::string >( std::cerr, " " ) );
-        std::cerr << std::endl;
-    }
+    //if ( ! cmd_parser.invalidOptions().empty() )
+    //{
+    //    std::cerr << "player: ***WARNING*** detected invalid options: ";
+    //    cmd_parser.printError( std::cerr );
+    //    std::cerr << std::endl;
+    //}
 
     setDebugFlags();
 
@@ -640,7 +634,7 @@ PlayerAgent::handleMessage()
     while ( recvMessage() > 0 )
     {
         ++counter;
-        parse( getRecvBuf() );
+        parse( recvBuf() );
     }
 
     // game cycle is change while several message parsing
@@ -1216,26 +1210,26 @@ PlayerAgent::analyzeHearPlayer(  const char * msg )
     {
         switch ( M_impl->audio_.playerMessage().type_ ) {
         case PlayerMessage::BALL_INFO:
-            M_worldmodel.setHeardBallInfo( M_impl->audio_.getBallPos(),
-                                           M_impl->audio_.getBallVel(),
+            M_worldmodel.setHeardBallInfo( M_impl->audio_.ballPos(),
+                                           M_impl->audio_.ballVel(),
                                            M_impl->current_time_ );
             break;
         case PlayerMessage::PASS_INFO:
-            M_worldmodel.setHeardPassInfo( M_impl->audio_.getReceiverNumber(),
-                                           M_impl->audio_.getReceivePos(),
+            M_worldmodel.setHeardPassInfo( M_impl->audio_.receiverNumber(),
+                                           M_impl->audio_.receivePos(),
                                            M_impl->current_time_ );
             break;
         case PlayerMessage::OPPONENT_GOALIE_INFO:
-            M_worldmodel.setHeardGoalieInfo( M_impl->audio_.getGoalieNumber(),
-                                             M_impl->audio_.getGoaliePos(),
+            M_worldmodel.setHeardGoalieInfo( M_impl->audio_.goalieNumber(),
+                                             M_impl->audio_.goaliePos(),
                                              M_impl->current_time_ );
             break;
         case PlayerMessage::OFFSIDE_LINE_INFO:
-            M_worldmodel.setHeardOffsideLineInfo( M_impl->audio_.getOffsideLineX(),
+            M_worldmodel.setHeardOffsideLineInfo( M_impl->audio_.offsideLineX(),
                                                   M_impl->current_time_ );
             break;
         case PlayerMessage::DEFENSE_LINE_INFO:
-            M_worldmodel.setHeardDefenseLineInfo( M_impl->audio_.getDefenseLineX(),
+            M_worldmodel.setHeardDefenseLineInfo( M_impl->audio_.defenseLineX(),
                                                   M_impl->current_time_ );
             break;
         case PlayerMessage::WAIT_REQUEST:
@@ -1244,7 +1238,9 @@ PlayerAgent::analyzeHearPlayer(  const char * msg )
         case PlayerMessage::ATTACK_REQUEST:
             M_worldmodel.setHeardAttackRequest( M_impl->current_time_ );
             break;
-        case PlayerMessage::NULL_INFO:
+        case PlayerMessage::INTERCEPT:
+        case PlayerMessage::HEY_PASS:
+        case PlayerMessage::ILLEGAL:
         default:
             break;
         }
@@ -1693,23 +1689,9 @@ PlayerAgent::action()
     dlog.addText( Logger::SYSTEM,
                   "decide action" );
 
-    if ( world().self().unum() == 0 )
-    {
-        static int s_no_init_count = 0;
-        s_no_init_count++;
-        std::cerr << config().teamName()
-                  << " -------------------- not initialized ... "
-                  << s_no_init_count << std::endl;
-        if ( s_no_init_count > 20 )
-        {
-            setServerAlive( false );
-        }
-        return;
-    }
-
     // check see synchronization
     if ( M_impl->see_state_.isSynch()
-         && M_impl->see_state_.getCyclesTillNextSee() == 0
+         && M_impl->see_state_.cyclesTillNextSee() == 0
          && world().seeTime() != M_impl->current_time_ )
     {
         dlog.addText( Logger::SYSTEM,
@@ -1866,8 +1848,8 @@ PlayerAgent::adjustSeeSynchNormalMode()
                       ostrm.str().c_str() );
 
         M_effector.incCommandCount( PlayerCommand::CHANGE_VIEW );
-        M_worldmodel.setViewMode( com.getWidth(), com.getQuality() );
-        M_impl->see_state_.setViewMode( com.getWidth(), com.getQuality() );
+        M_worldmodel.setViewMode( com.width(), com.quality() );
+        M_impl->see_state_.setViewMode( com.width(), com.quality() );
 
         std::cout << world().teamName() << ' '
                   << world().self().unum() << ": "
@@ -1894,8 +1876,8 @@ PlayerAgent::adjustSeeSynchNormalMode()
                           ostrm.str().c_str() );
 
             M_effector.incCommandCount( PlayerCommand::CHANGE_VIEW );
-            M_worldmodel.setViewMode( com.getWidth(), com.getQuality() );
-            M_impl->see_state_.setViewMode( com.getWidth(), com.getQuality() );
+            M_worldmodel.setViewMode( com.width(), com.quality() );
+            M_impl->see_state_.setViewMode( com.width(), com.quality() );
         }
         return;
     }
@@ -1915,8 +1897,8 @@ PlayerAgent::adjustSeeSynchNormalMode()
                       ostrm.str().c_str() );
 
         M_effector.incCommandCount( PlayerCommand::CHANGE_VIEW );
-        M_worldmodel.setViewMode( com.getWidth(), com.getQuality() );
-        M_impl->see_state_.setViewMode( com.getWidth(), com.getQuality() );
+        M_worldmodel.setViewMode( com.width(), com.quality() );
+        M_impl->see_state_.setViewMode( com.width(), com.quality() );
 
         std::cerr << world().teamName() << ' '
                   << world().self().unum() << ": "
@@ -1954,8 +1936,8 @@ PlayerAgent::adjustSeeSynchSynchMode()
                       ostrm.str().c_str() );
 
         M_effector.incCommandCount( PlayerCommand::CHANGE_VIEW );
-        M_worldmodel.setViewMode( com.getWidth(), com.getQuality() );
-        M_impl->see_state_.setViewMode( com.getWidth(), com.getQuality() );
+        M_worldmodel.setViewMode( com.width(), com.quality() );
+        M_impl->see_state_.setViewMode( com.width(), com.quality() );
 
         std::cout << world().teamName() << ' '
                   << world().self().unum() << ": "
@@ -1982,8 +1964,8 @@ PlayerAgent::adjustSeeSynchSynchMode()
                           ostrm.str().c_str() );
 
             M_effector.incCommandCount( PlayerCommand::CHANGE_VIEW );
-            M_worldmodel.setViewMode( com.getWidth(), com.getQuality() );
-            M_impl->see_state_.setViewMode( com.getWidth(), com.getQuality() );
+            M_worldmodel.setViewMode( com.width(), com.quality() );
+            M_impl->see_state_.setViewMode( com.width(), com.quality() );
         }
         return;
     }
@@ -2003,8 +1985,8 @@ PlayerAgent::adjustSeeSynchSynchMode()
                       ostrm.str().c_str() );
 
         M_effector.incCommandCount( PlayerCommand::CHANGE_VIEW );
-        M_worldmodel.setViewMode( com.getWidth(), com.getQuality() );
-        M_impl->see_state_.setViewMode( com.getWidth(), com.getQuality() );
+        M_worldmodel.setViewMode( com.width(), com.quality() );
+        M_impl->see_state_.setViewMode( com.width(), com.quality() );
 
         std::cerr << world().teamName() << ' '
                   << world().self().unum() << ": "
