@@ -32,13 +32,13 @@
 #ifndef RCSC_PLAYER_COMMAND_H
 #define RCSC_PLAYER_COMMAND_H
 
+#include <rcsc/player/view_mode.h>
+#include <rcsc/geom/angle_deg.h>
+
 #include <string>
 #include <iostream>
 #include <cmath>
 
-#include <rcsc/geom/angle_deg.h>
-#include <rcsc/player/view_mode.h>
-
 namespace rcsc {
 
 /*!
@@ -802,7 +802,7 @@ public:
       \brief ViewWidth of this command
     */
     const
-    ViewWidth & getWidth() const
+    ViewWidth & width() const
       {
           return M_width;
       }
@@ -812,7 +812,7 @@ public:
       \brief ViewQuality of this command
     */
     const
-    ViewQuality & getQuality() const
+    ViewQuality & quality() const
       {
           return M_quality;
       }
@@ -1035,7 +1035,7 @@ public:
       \brief get target player's side type
       \return target player's side type
     */
-    SideType getSideType() const
+    SideType side() const
       {
           return M_side;
       }
@@ -1044,7 +1044,7 @@ public:
       \brief get target player's uniform number
       \return target player's uniform number
     */
-    int getNumber() const
+    int number() const
       {
           return M_number;
       }
