@@ -30,33 +30,31 @@
 /////////////////////////////////////////////////////////////////////
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
-#include <cmath>
-#include <cassert>
-#include <algorithm>
-#include <iterator>
-
-#include <rcsc/math_util.h>
-#include <rcsc/soccer_math.h>
-
-#include <rcsc/param/player_param.h>
-#include <rcsc/param/server_param.h>
+#include "world_model.h"
 
 #include "action_effector.h"
+#include "localization.h"
 #include "body_sensor.h"
 #include "visual_sensor.h"
 #include "fullstate_sensor.h"
 #include "debug_client.h"
 #include "intercept_table.h"
-#include "localization.h"
 #include "logger.h"
 #include "penalty_kick_state.h"
 #include "player_command.h"
 
-#include "world_model.h"
+#include <rcsc/param/player_param.h>
+#include <rcsc/param/server_param.h>
+#include <rcsc/soccer_math.h>
+#include <rcsc/math_util.h>
 
+#include <iterator>
+#include <algorithm>
+#include <cassert>
+#include <cmath>
 
 namespace rcsc {
 
@@ -64,8 +62,8 @@ class WMImpl {
 public:
 
     /*!
-      
-    */    
+
+    */
     inline
     static
     void create_player_set( rcsc::PlayerCont & players,
@@ -73,7 +71,7 @@ public:
                             rcsc::PlayerPtrCont & players_from_ball,
                             const rcsc::Vector2D & self_pos,
                             const rcsc::Vector2D & ball_pos )
-        
+
       {
           const rcsc::PlayerCont::iterator end = players.end();
           for ( rcsc::PlayerCont::iterator it = players.begin();
@@ -87,7 +85,7 @@ public:
       }
 
     /*!
-      
+
     */
     inline
     static
@@ -101,22 +99,22 @@ public:
               {
                   continue;
               }
-              
+
               if ( (*first)->isKickable() )
               {
                   return true;
               }
-              
+
               return false;
           }
-          
+
           return false;
       }
 
     typedef boost::shared_ptr< rcsc::Localization::PlayerT > LPPtr;
 
     /*!
-      
+
     */
     inline
     static
@@ -129,17 +127,17 @@ public:
           for ( ; first != last; ++first )
           {
               rcsc::Localization::PlayerT * player = new rcsc::Localization::PlayerT();
-              
+
               localize->localizePlayer( *first,
                                         self.face().degree(),
                                         self.faceError(),
                                         self.pos(),
                                         self.vel(),
                                         player );
-              
+
               localized_players.push_back( LPPtr( player ) );
           }
-          
+
       }
 };
 
@@ -260,7 +258,7 @@ WorldModel::~WorldModel()
 */
 const
 InterceptTable *
-WorldModel::getInterceptTable() const
+WorldModel::interceptTable() const
 {
     assert( M_intercept_table );
     return M_intercept_table;
@@ -272,7 +270,7 @@ WorldModel::getInterceptTable() const
 */
 const
 PenaltyKickState *
-WorldModel::getPenaltyKickState() const
+WorldModel::penaltyKickState() const
 {
     assert( M_penalty_kick_state );
     return M_penalty_kick_state;
@@ -697,15 +695,15 @@ WorldModel::updateAfterFullstate( const FullstateSensor & fullstate,
                   "*************** updateAfterFullstate ***************" );
 
     // update players
-    const FullstateSensor::PlayerCont & our_players 
+    const FullstateSensor::PlayerCont & our_players
         = ( isOurLeft()
             ? fullstate.leftTeam()
             : fullstate.rightTeam() );
-    const FullstateSensor::PlayerCont & opp_players 
+    const FullstateSensor::PlayerCont & opp_players
         = ( isOurLeft()
             ? fullstate.rightTeam()
             : fullstate.leftTeam() );
-    
+
     // clean unkown players
     M_unknown_teammates.clear();
     M_unknown_opponents.clear();
@@ -1034,27 +1032,27 @@ WorldModel::updateJustBeforeDecision( const ActionEffector & act,
 void
 WorldModel::setCommandEffect( const ActionEffector & act )
 {
-    if ( act.getChangeViewCommand() )
+    if ( act.changeViewCommand() )
     {
-        M_self.setViewMode( act.getChangeViewCommand()->getWidth(),
-                            act.getChangeViewCommand()->getQuality() );
+        M_self.setViewMode( act.changeViewCommand()->width(),
+                            act.changeViewCommand()->quality() );
     }
 
-    if ( act.getPointtoCommand() )
+    if ( act.pointtoCommand() )
     {
         M_self.setPointto( act.getPointtoPos(),
                            time() );
     }
 
-    const PlayerAttentiontoCommand * attentionto = act.getAttentiontoCommand();
+    const PlayerAttentiontoCommand * attentionto = act.attentiontoCommand();
     if ( attentionto )
     {
         if ( attentionto->isOn() )
         {
-            if ( attentionto->getSideType() == PlayerAttentiontoCommand::OUR )
+            if ( attentionto->side() == PlayerAttentiontoCommand::OUR )
             {
                 M_self.setAttentionto( ourSide(),
-                                       attentionto->getNumber() );
+                                       attentionto->number() );
             }
             else
             {
@@ -1062,7 +1060,7 @@ WorldModel::setCommandEffect( const ActionEffector & act )
                                     ? RIGHT
                                     : LEFT );
                 M_self.setAttentionto( opp_side,
-                                       attentionto->getNumber() );
+                                       attentionto->number() );
             }
         }
         else
@@ -1085,7 +1083,7 @@ WorldModel::localizeSelf( const VisualSensor::LineCont & lines,
                           const GameTime & current )
 {
     double angle_face = -360.0, angle_face_error = 0.0;
-    Vector2D my_pos( Vector2D::INVALID );
+    Vector2D my_pos( Vector2D::INVALIDATED );
     Vector2D my_pos_error( 0.0, 0.0 );
 
     //////////////////////////////////////////////////////////////////
@@ -1127,9 +1125,9 @@ WorldModel::localizeBall( const VisualSensor::BallCont & balls,
     //////////////////////////////////////////////////////////////////
     // calc relative info
 
-    Vector2D rpos( Vector2D::INVALID );
+    Vector2D rpos( Vector2D::INVALIDATED );
     Vector2D rpos_error( 0.0, 0.0 );
-    Vector2D rvel( Vector2D::INVALID );
+    Vector2D rvel( Vector2D::INVALIDATED );
     Vector2D vel_error( 0.0, 0.0 );
 
     M_localize
@@ -1153,9 +1151,9 @@ WorldModel::localizeBall( const VisualSensor::BallCont & balls,
         if ( ball().rposCount() == 1
              && ( balls.front().dist_
                   > self().playerType().playerSize() + ServerParam::i().ballSize() + 0.1 )
-             && self().getLastMove().valid() )
+             && self().lastMove().valid() )
         {
-            Vector2D tvel = ( rpos - ball().rposPrev() ) + self().getLastMove();
+            Vector2D tvel = ( rpos - ball().rposPrev() ) + self().lastMove();
             Vector2D tvel_err = rpos_error + self().velError();
             // set only vel
             tvel *= ServerParam::i().ballDecay();
@@ -1182,7 +1180,7 @@ WorldModel::localizeBall( const VisualSensor::BallCont & balls,
 
     Vector2D pos = self().pos() + rpos;
     Vector2D pos_error = self().posError() + rpos_error;
-    Vector2D gvel( Vector2D::INVALID );
+    Vector2D gvel( Vector2D::INVALIDATED );
 
     if ( rvel.valid()
          && self().velValid() )
@@ -1213,11 +1211,11 @@ WorldModel::localizeBall( const VisualSensor::BallCont & balls,
         if ( ball().rposCount() == 1 // we saw the ball at prev cycle, too.
              && balls.front().dist_ < 3.15 // ServerParam::i().visibleDistance()
              && self().velValid()
-             && self().getLastMove().valid() )
+             && self().lastMove().valid() )
         {
             Vector2D rpos_diff = rpos - ball().rposPrev();
             gvel = rpos_diff;// - ball().rposPrev();
-            gvel += self().getLastMove();
+            gvel += self().lastMove();
             vel_error = rpos_error + self().velError();
             gvel *= ServerParam::i().ballDecay();
             vel_error *= ServerParam::i().ballDecay();
@@ -1239,8 +1237,8 @@ WorldModel::localizeBall( const VisualSensor::BallCont & balls,
                           rpos_diff.x, rpos_diff.y,
                           ball().rposPrev().x, ball().rposPrev().y,
                           gvel.x, gvel.y,
-                          self().getLastMove().x,
-                          self().getLastMove().y );
+                          self().lastMove().x,
+                          self().lastMove().y );
         }
     }
 
@@ -2038,7 +2036,7 @@ WorldModel::updatePlayerMatrix()
                   "WorldModel::updatePlayerMatrix()" );
 
     WMImpl::create_player_set( M_teammates,
-                               M_teammates_from_self, 
+                               M_teammates_from_self,
                                M_teammates_from_ball,
                                self().pos(),
                                ball().pos() );
@@ -2047,22 +2045,22 @@ WorldModel::updatePlayerMatrix()
                                M_teammates_from_ball,
                                self().pos(),
                                ball().pos() );
-    WMImpl::create_player_set( M_opponents, 
+    WMImpl::create_player_set( M_opponents,
                                M_opponents_from_self,
                                M_opponents_from_ball,
                                self().pos(),
                                ball().pos() );
-    WMImpl::create_player_set( M_unknown_opponents, 
-                               M_opponents_from_self,
-                               M_opponents_from_ball,
-                               self().pos(), 
-                               ball().pos() );
-    WMImpl::create_player_set( M_unknown_players, 
+    WMImpl::create_player_set( M_unknown_opponents,
                                M_opponents_from_self,
                                M_opponents_from_ball,
                                self().pos(),
                                ball().pos() );
-    
+    WMImpl::create_player_set( M_unknown_players,
+                               M_opponents_from_self,
+                               M_opponents_from_ball,
+                               self().pos(),
+                               ball().pos() );
+
     // sort by distance to self or ball
     std::sort( M_teammates_from_self.begin(),
                M_teammates_from_self.end(),
@@ -2070,7 +2068,7 @@ WorldModel::updatePlayerMatrix()
     std::sort( M_opponents_from_self.begin(),
                M_opponents_from_self.end(),
                PlayerObject::PtrSelfDistCmp() );
-    
+
     std::sort( M_teammates_from_ball.begin(),
                M_teammates_from_ball.end(),
                PlayerObject::PtrBallDistCmp() );
@@ -2079,7 +2077,7 @@ WorldModel::updatePlayerMatrix()
                PlayerObject::PtrBallDistCmp() );
 
     // check kickable player
-    M_exist_kickable_teammate 
+    M_exist_kickable_teammate
         = WMImpl::check_player_kickable( M_teammates_from_ball.begin(),
                                          M_teammates_from_ball.end(),
                                          ball().posCount() );
