@@ -30,15 +30,15 @@
 /////////////////////////////////////////////////////////////////////
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
-#include "types.h"
+#include "factory.h"
+
 #include "parser_v1.h"
 #include "parser_v2.h"
 #include "parser_v3.h"
-
-#include "factory.h"
+#include "types.h"
 
 namespace rcsc {
 namespace rcg {
