@@ -30,24 +30,23 @@
 /////////////////////////////////////////////////////////////////////
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
-#include <sstream>
-#include <algorithm>
-#include <iterator>
+#include "trainer_agent.h"
+
+#include "trainer_command.h"
+
+#include <rcsc/coach/global_visual_sensor.h>
 
-#include <rcsc/random.h>
 #include <rcsc/param/server_param.h>
 #include <rcsc/param/player_param.h>
 #include <rcsc/param/player_type.h>
 #include <rcsc/param/param_map.h>
 #include <rcsc/param/conf_file_parser.h>
 #include <rcsc/param/cmd_line_parser.h>
-#include <rcsc/coach/global_visual_sensor.h>
 
-#include "trainer_command.h"
-#include "trainer_agent.h"
+#include <sstream>
 
 namespace rcsc {
 
@@ -202,23 +201,19 @@ TrainerAgent::visualSensor() const
 
 */
 bool
-TrainerAgent::doInit( const int argc,
-                      const char * const * argv )
+TrainerAgent::doInit( CmdLineParser & cmd_parser )
 {
     bool help = false;
     std::string trainer_config_file;
 
     ParamMap system_param_map( "System options" );
     system_param_map.add()
-        ( BoolSwitch( &help ), "help" , "", "print help message.")
-        ( &trainer_config_file, "trainer-config", "", "specifies trainer config file." );
+        ( "help" , "", BoolSwitch( &help ), "print help message.")
+        ( "trainer-config", "", &trainer_config_file, "specifies trainer config file." );
 
     ParamMap trainer_param_map( "Trainer options" );
     M_config.createParamMap( trainer_param_map );
 
-
-    CmdLineParser cmd_parser( argc, argv );
-
     // analyze command line for system options.
     cmd_parser.parse( system_param_map );
     if ( help )
@@ -239,14 +234,12 @@ TrainerAgent::doInit( const int argc,
     // analyze command line for trainer options.
     cmd_parser.parse( trainer_param_map );
 
-    if ( ! cmd_parser.invalidOptions().empty() )
-    {
-        std::cerr << "trainer: ***WARNING*** detected invalid options: ";
-        std::copy( cmd_parser.invalidOptions().begin(),
-                   cmd_parser.invalidOptions().end(),
-                   std::ostream_iterator< std::string >( std::cerr, " " ) );
-        std::cerr << std::endl;
-    }
+    //if ( ! cmd_parser.invalidOptions().empty() )
+    //{
+    //  std::cerr << "trainer: ***WARNING*** detected invalid options: ";
+    //    cmd_parser.printError( std::cerr );
+    //    std::cerr << std::endl;
+    //}
     return true;
 }
 
@@ -322,7 +315,7 @@ TrainerAgent::handleMessage()
 
     while ( recvMessage() > 0 )
     {
-        parse( getRecvBuf() );
+        parse( recvBuf() );
     }
 
     if ( M_impl->think_received_ )
